% 
% This file generates necessary open and closed loop Linear F/A-18 models 
% for the analysis purpose around the trim point specified. Both baseline 
% and revised closed loop models are genrated. The models are generated for 
% a certian air speed and a certain bank angle turn (both coordinated and
% uncoordinated).  
%
% NOTE: The linear models should be saved the first time the file is run.
% Set savelflg = 1  to save the files. Later on, these files are used for
% the analysis. 
%

% Abhijit 11/18/2009

saveflg = 1; 

%------------ Run the AERODYNAMIC Model
F18_AeroData = 1; 
f18_data; 

% ---------- Define Trim Points 
V0 = 350;                       % Velocity
phi0grid = [0 10 25 35]*d2r;    % Bank angle

Level = 0;                      % Level flight

%-------------------------------------------------------
% Generate Models 


for i1 = 1:length(phi0grid)
    
    % -------------------------------------------------
    % Coordinated  Turn 
    clear phi0
    CoordTurn = 1;     
    UnCoordTurn = 0;     
    phi0 = phi0grid(i1); 
    
    % --------------Generate Variable Name
    V1 = strcat('F18Model_Coord_Phi_',num2str(phi0*r2d));
    
    GenF18LinModel; 
    GenF18LinCLPModel;  
    
    % --------------- Save Data    
    if saveflg 
        save(V1,'xtrim','utrim','Pss','CssB','CLB','CssR','CLR','linsys');
    end
    
    % -------------------------------------------------
    % UnCoordinated  Turn 
    clear phi0 
    CoordTurn = 0; 
    UnCoordTurn = 1;     
    phi0 = phi0grid(i1); 
   
    % --------------Generate Variable Name
    V2 = strcat('F18Model_UnCoord_Phi_',num2str(phi0*r2d));
    
    GenF18LinModel; 
    GenF18LinCLPModel;  
    
    % --------------- Save Data
        if saveflg 
            save(V2,'xtrim','utrim','Pss','CssB','CLB','CssR','CLR','linsys');
        end
end

