%
% This file runs the ROA V-S Iteration and Monte Carlo Simulation for F/A-18 
% The user should be able to set either (i) Lower Bound (V-s / Mintrace) 
% iteration (ii) upper bound via Monte Carlo simulation needs to be
% performed. 

% Abhijit 03/05/2010

%---------------------------------------------------------

LB = 1; 
UB = 0; 
d2r = pi/180; r2d = 1/ d2r;

    
% --------------------------------------------------------------------
% Run Revised

if exist('1_PolyF18RevisedModel_Phi_35.mat') == 2
   load 1_PolyF18RevisedModel_Phi_35;
else
   FormF18CubicRevised;   
end

% Extract the model 
f = cleanpoly(xcldotR,10^-06);

% create the shape ellipsoid 
Dmax = diag([10*d2r 25*d2r 35*d2r 30*d2r 15*d2r 25*d2r 20*d2r]);  
N = inv(Dmax^2);   %  Scale by inverse of max state values
p = x'*N*x;

if LB
    % create roaoptions object and run roaest
    Vdeg = 4; 
    zV = monomials(x,2:Vdeg); 
    L2 =  1e-6*(x'*x);
    NstepMinTrace = 60;
    z1maxd = ceil((Vdeg-p.maxdeg)/2);
    z1 = monomials(x, 0:z1maxd ); 
    z2 = monomials(x, 0:1 );
    ropt = roaoptions(f,x,'zV',zV,'p',p,'L2',L2,'NstepMinTrace',...
           NstepMinTrace,'z1',z1,'z2',z2,'display','on','MinTrace',0);
    
    [betaR,VR,gammaR,s1R,s2R,iterR] = roaest(f,x,ropt);
    
elseif UB
    V0 = strcat('1_ROAMC_F18Revised_',num2str(xtrim(7)*r2d));
    Search4UnstableTraj;
end


% --------------------------------------------------------------------
% Run Baseline 

if exist('1_PolyF18BaselineModel_Phi_35.mat') == 2
   load 1_PolyF18BaselineModel_Phi_35;
else
   FormF18CubicBaseline;   
end

% Extract the model 
f = cleanpoly(xcldotB,10^-06);

% create the shape ellipsoid 
Dmax = diag([10*d2r 25*d2r 35*d2r 30*d2r 15*d2r 25*d2r 20*d2r]);  
N = inv(Dmax^2);   %  Scale by inverse of max state values
p = x'*N*x;

if LB
    % create roaoptions object and run roaest
    Vdeg = 4; 
    zV = monomials(x,2:Vdeg); 
    L2 =  1e-6*(x'*x);
    NstepMinTrace = 60;
    z1maxd = ceil((Vdeg-p.maxdeg)/2);
    z1 = monomials(x, 0:z1maxd ); 
    z2 = monomials(x, 0:1 );
    ropt = roaoptions(f,x,'zV',zV,'p',p,'L2',L2,'NstepMinTrace',...
           NstepMinTrace,'z1',z1,'z2',z2,'display','on','MinTrace',0);
    [betaB,VB,gammaB,s1B,s2B,iterB] = roaest(f,x,ropt);

elseif UB
    V0 = strcat('1_ROAMC_F18BaseLine_',num2str(xtrim(7)*r2d));
    Search4UnstableTraj;
end


